@@ -35,7 +35,7 @@
  ****************************************************************************/
 
 /*
- * $Id: curses.priv.h,v 1.676 2023/09/23 18:46:47 tom Exp $
+ * $Id: curses.priv.h,v 1.668 2023/06/03 12:33:07 tom Exp $
  *
  *	curses.priv.h
  *
@@ -144,14 +144,14 @@ extern int errno;
 #if (defined(__USE_MINGW_ANSI_STDIO) && __USE_MINGW_ANSI_STDIO != 0) && (defined(__GNUC__) && (__GNUC__ < 12))
 # undef PRIxPTR		/* gcc bug fixed in 12.x */
 # define PRIxPTR	"lX"
-# define CASTxPTR(n)    (unsigned long)(intptr_t)(void*)(n)
+# define CASTxPTR(n)    (unsigned long)(intptr_t)(n)
 #else
 # define CASTxPTR(n)    (intptr_t)(n)
 #endif
 
 #ifndef PRIxPTR
 # define PRIxPTR	"lx"
-# define CASTxPTR(n)    (long)(void*)(n)
+# define CASTxPTR(n)    (long)(n)
 #endif
 
 /* include signal.h before curses.h to work-around defect in glibc 2.1.3 */
@@ -312,6 +312,7 @@ extern NCURSES_EXPORT(void *) _nc_memmove (void *, const void *, size_t);
 #define NO_TERMINAL "unknown"
 #define USE_SP_RIPOFF     1
 #define USE_SP_TERMTYPE   1
+#define USE_SP_WINDOWLIST 1
 #else
 #define NO_TERMINAL 0
 #endif
@@ -322,12 +323,6 @@ extern NCURSES_EXPORT(void *) _nc_memmove (void *, const void *, size_t);
 		     : no_terminal), \
 	 NonEmpty(term_env))
 
-/*
- * Originally a terminal-driver option, the window-list is per-screen to allow
- * freeing memory used for windows when a screen is deleted.
- */
-#define USE_SP_WINDOWLIST 1
-
 /*
  * Note:  ht/cbt expansion flakes out randomly under Linux 1.1.47, but only
  * when we're throwing control codes at the screen at high volume.  To see
@@ -350,11 +345,6 @@ typedef TRIES {
  */
 #define StringOf(ch) {ch, 0}
 
-#define CSI_CHR 0x9b
-#define ESC_CHR 0x1b
-
-#define L_BLOCK '['
-#define R_BLOCK ']'
 #define L_BRACE '{'
 #define R_BRACE '}'
 #define S_QUOTE '\''
@@ -584,10 +574,10 @@ extern NCURSES_EXPORT(void)     _nc_set_no_padding(SCREEN *);
 #define SET_SCREEN_PAIR(s,p)	SetPair(SCREEN_ATTRS(s), p)
 
 #if USE_REENTRANT || NCURSES_SP_FUNCS
-extern NCURSES_EXPORT(int *)    _nc_ptr_Lines (SCREEN *);
-extern NCURSES_EXPORT(int *)    _nc_ptr_Cols (SCREEN *);
-extern NCURSES_EXPORT(int *)    _nc_ptr_Tabsize (SCREEN *);
-extern NCURSES_EXPORT(int *)    _nc_ptr_Escdelay (SCREEN *);
+NCURSES_EXPORT(int *)        _nc_ptr_Lines (SCREEN *);
+NCURSES_EXPORT(int *)        _nc_ptr_Cols (SCREEN *);
+NCURSES_EXPORT(int *)        _nc_ptr_Tabsize (SCREEN *);
+NCURSES_EXPORT(int *)        _nc_ptr_Escdelay (SCREEN *);
 #endif
 
 #if USE_REENTRANT
@@ -885,12 +875,6 @@ typedef int (*TYPE_Gpm_GetEvent) (Gpm_Event *);
 #endif /* HAVE_LIBDL */
 #endif /* USE_GPM_SUPPORT */
 
-/*
- * Limit delay-times to 30 seconds, which is consistent with signed 16-bit
- * numbers in legacy terminfo.
- */
-#define MAX_DELAY_MSECS 30000
-
 /*
  * When converting from terminfo to termcap, check for cases where we can trim
  * octal escapes down to 2-character form.  It is useful for terminfo format
@@ -1308,12 +1292,12 @@ extern NCURSES_EXPORT_VAR(SIG_ATOMIC_T) _nc_have_sigwinch;
 /* Checks for isprint() should be done on 8-bit characters (non-wide) */
 #define is8bits(c)	((unsigned)(c) <= UCHAR_MAX)
 
-#ifndef Min
-#define Min(a,b)	((a) > (b)  ?  (b)  :  (a))
+#ifndef min
+#define min(a,b)	((a) > (b)  ?  (b)  :  (a))
 #endif
 
-#ifndef Max
-#define Max(a,b)	((a) < (b)  ?  (b)  :  (a))
+#ifndef max
+#define max(a,b)	((a) < (b)  ?  (b)  :  (a))
 #endif
 
 /* usually in <unistd.h> */
@@ -1514,7 +1498,7 @@ extern NCURSES_EXPORT_VAR(SIG_ATOMIC_T) _nc_have_sigwinch;
 #define isWidecExt(ch)	(0)
 #define if_WIDEC(code) /* nothing */
 
-#define Charable(ch)	(CharOf(ch) >= ' ' && CharOf(ch) <= '~')
+#define Charable(ch)	((ch) >= ' ' && (ch) <= '~')
 #define L(ch)		ch
 #endif /* } */
 
@@ -1556,9 +1540,6 @@ extern NCURSES_EXPORT_VAR(SIG_ATOMIC_T) _nc_have_sigwinch;
 
 #define SIZEOF(v) (sizeof(v)/sizeof(v[0]))
 
-#include <nc_alloc.h>
-#include <nc_access.h>
-
 #define FreeIfNeeded(p)  if ((p) != 0) free(p)
 
 /* FreeAndNull() is not a comma-separated expression because some compilers
@@ -1566,18 +1547,8 @@ extern NCURSES_EXPORT_VAR(SIG_ATOMIC_T) _nc_have_sigwinch;
  */
 #define FreeAndNull(p)   do { free(p); p = 0; } while (0)
 
-#ifdef EXP_OOM_TESTING
-extern NCURSES_EXPORT(void *)	_nc_oom_malloc(size_t size);
-extern NCURSES_EXPORT(void *)	_nc_oom_calloc(size_t nmemb, size_t size);
-extern NCURSES_EXPORT(void *)	_nc_oom_realloc(void *ptr, size_t size);
-extern NCURSES_EXPORT(void)	_nc_oom_free(void *ptr);
-extern NCURSES_EXPORT(char *)	_nc_oom_strdup(const char *ptr);
-#define malloc(size)		_nc_oom_malloc(size)
-#define calloc(nmemb, size)	_nc_oom_calloc(nmemb, size)
-#define realloc(ptr, size)	_nc_oom_realloc(ptr, size)
-#define free(ptr)		_nc_oom_free(ptr)
-#define strdup(ptr)		_nc_oom_strdup(ptr)
-#endif
+#include <nc_alloc.h>
+#include <nc_access.h>
 
 /*
  * Use these for tic/infocmp malloc failures.  Generally the ncurses library
@@ -1997,7 +1968,7 @@ extern NCURSES_EXPORT(int)  _nc_msec_cost (const char *const, int);
 
 /* lib_addch.c */
 #if USE_WIDEC_SUPPORT
-extern NCURSES_EXPORT(int) _nc_build_wch(WINDOW *win, ARG_CH_T ch);
+NCURSES_EXPORT(int) _nc_build_wch(WINDOW *win, ARG_CH_T ch);
 #endif
 
 /* lib_addstr.c */
@@ -2176,7 +2147,7 @@ extern NCURSES_EXPORT(const TERMTYPE2 *) _nc_fallback2 (const char *);
 #define _nc_fallback2(tp) _nc_fallback(tp)
 #endif
 
-extern NCURSES_EXPORT(void) _nc_copy_termtype(TERMTYPE *, const TERMTYPE *);
+NCURSES_EXPORT(void) _nc_copy_termtype(TERMTYPE *, const TERMTYPE *);
 
 #if NCURSES_EXT_NUMBERS
 extern NCURSES_EXPORT(void) _nc_copy_termtype2 (TERMTYPE2 *, const TERMTYPE2 *);
@@ -2258,7 +2229,7 @@ extern int __MINGW_NOTHROW _nc_mblen(const char *, size_t);
 
 #if defined(_NC_WINDOWS) || defined(_NC_MINGW)
 /* see wcwidth.c */
-extern NCURSES_EXPORT(int) mk_wcwidth(wchar_t);
+NCURSES_EXPORT(int) mk_wcwidth(wchar_t);
 #define wcwidth(ucs) _nc_wcwidth(ucs)
 #endif
 
@@ -2650,8 +2621,8 @@ extern NCURSES_EXPORT(NCURSES_CONST char *) _nc_unctrl (SCREEN *, chtype);
 #endif
 
 #ifdef EXP_XTERM_1005
-extern NCURSES_EXPORT(int) _nc_conv_to_utf8(unsigned char *, unsigned, unsigned);
-extern NCURSES_EXPORT(int) _nc_conv_to_utf32(unsigned *, const char *, unsigned);
+NCURSES_EXPORT(int) _nc_conv_to_utf8(unsigned char *, unsigned, unsigned);
+NCURSES_EXPORT(int) _nc_conv_to_utf32(unsigned *, const char *, unsigned);
 #endif
 
 #ifdef __cplusplus
